OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informace o procesoru nejsou k dispozici",
    "Load average" : "Průměrné vytížení",
    "Last minute" : "Poslední minuta",
    "Memory info not available" : "Informace o operační paměti není dostupná",
    "Total" : "Celkem",
    "Current usage" : "Aktuální využití",
    "Users" : "Uživatelé",
    "Groups" : "Skupiny",
    "Links" : "Odkazy",
    "Mails" : "E-maily",
    "Federated sent" : "Federovaně odesláno",
    "Federated received" : "Federovaně přijato",
    "Talk conversations" : "Konverzace v Talk",
    "24 hours" : "24 hodin",
    "1 hour" : "1 hodina",
    "5 mins" : "5 minut",
    "Copy" : "Zkopírovat",
    "Copied!" : "Zkopírováno",
    "Not supported!" : "Nepodporováno!",
    "Press ⌘-C to copy." : "Zkopírujete stisknutím ⌘C.",
    "Press Ctrl-C to copy." : "Zkopírujete stisknutím Ctrl+C.",
    "System" : "Systém",
    "Monitoring" : "Dohledování",
    "Monitoring app with useful server information" : "Dohledovací aplikace s užitečnými informacemi o serveru",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Poskytuje užitečné informace o serveru, jako vytížení procesoru, využití operační paměti, obsazenost datového úložiště, počet uživatelů, atd.",
    "Operating System" : "Operační systém",
    "CPU" : "Procesor",
    "Memory" : "Operační paměť",
    "Server time" : "Čas na serveru",
    "Uptime" : "Doba chodu od minulého zapnutí",
    "Load" : "Vytížení",
    "Disk" : "Úložiště",
    "Mount" : "Připojení (mount)",
    "Filesystem" : "Souborový systém",
    "Size" : "Velikost",
    "Available" : "K dispozici",
    "Used" : "Použito",
    "You will get a notification once one of your disks is nearly full." : "Pokud budou vaše úložiště téměř zaplněná, budete na to upozorněni.",
    "Files:" : "Soubory:",
    "Storages:" : "Úložiště:",
    "Free Space:" : "Volné místo:",
    "Network" : "Síť",
    "Hostname" : "Název stroje",
    "DNS" : "DNS",
    "Gateway" : "Brána",
    "Status" : "Stav",
    "Speed" : "Rychlost",
    "MAC" : "MAC adresa",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Aktivní uživatelé",
    "Total users:" : "Celkem uživatelů:",
    "Shares" : "Sdílení",
    "PHP" : "PHP",
    "Version:" : "Verze:",
    "Memory Limit:" : "Limit paměti:",
    "Max Execution Time:" : "Nejdelší umožněný čas vykonávání:",
    "Upload max size:" : "Nejvyšší umožněná velikost nahrávaného souboru:",
    "Database" : "Databáze",
    "Type:" : "Typ:",
    "Size:" : "Velikost:",
    "External monitoring tool" : "Externí nástroj pro dohledování",
    "You can connect an external monitoring tool by using this end point:" : "Externí dohledovací nástroj je možné napojit pomocí tohoto koncového bodu:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Připojení \"?format=json\" na konec URL poskytne výsledek ve formátu JSON.",
    "Time Servers" : "Časové servery",
    "Did you know?" : "Věděli jste?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Přidáním „?format=json“ (bez uvozovek) na konci URL adresy získáte výsledek ve formátu JSON!"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
